//read ambient light & set the brightness of the LEDs (w/fading)
void readAmbLight() {
    byte tempRead = (analogRead(AMB_LIGHT) >> 2); //convert the light into a byte from 0..255 (0 = full light / 255 = full dark)
    if (tempRead > 246) { //set a minimum value for the light...
        tempRead = 246; //...to avoid having the LEDs off if it's too dark
    }
    readLedBrightness = tempRead;
}


//fade the LEDs with the value of the brightness
void writeAmbLight() {
    if (currentLedBrightness != readLedBrightness) { //is the current brightness different than the value read from the LDR?
        if (currentLedBrightness > readLedBrightness) { //if the current brightness is greater than the value read from the LDR...
            currentLedBrightness--; //...I decrement the current LEDs brightness...
        } else {
            currentLedBrightness++;//...otherwise I increment it
        }
        analogWrite(LED_POWER, currentLedBrightness); //set the new brightness
    }
}


//every 1 hr, I read the correct time from the external RTC
void readTime() {
    rtc.getTime(); //get the time
    //store the HH:MM:SS
    tSeconds = rtc.getSecond();
    tMinutes = rtc.getMinute();
    tHours = rtc.getHour();
}


//during the programming of the clock, I blinks the LEDs every ~330 ms
void blinkClock() {
    volatile static byte stat = ON;
    analogWrite(LED_POWER, stat);
    stat ^= OFF;
}


//PinChange Interrupt used to increment the local variables that keep current time
void incrementTime() {
    if (++tSeconds > 59) { //seconds overflow?
        tSeconds = 0;
        if (++tMinutes > 59) { //minutes overflow?
            tMinutes = 0;
            if (++tHours > 23) { //hours overflow?
                tHours = 0;
            }
        }
    }
    timeChanged = true;
}
